# taylorism

[![Custom CI](https://github.com/UMR-CNRM/taylorism/actions/workflows/lint_test_and_doc.yml/badge.svg)](https://github.com/UMR-CNRM/taylorism/actions/workflows/lint_test_and_doc.yml)
[![Documentation Status](https://readthedocs.org/projects/taylorism/badge/?version=latest)](https://taylorism.readthedocs.io/)
[![PyPI version](https://badge.fury.io/py/taylorism.svg)](https://badge.fury.io/py/taylorism)

*taylorism* is a framework for the parallelisation of tasks.

Originally, it has been developed as part of the *Vortex* project. Recently
the  code has been extracted from the *Vortex* code base. It is now presented
as an independent Python package.

The documentation is available on ReadTheDocs: [https://taylorism.readthedocs.io/](https://taylorism.readthedocs.io/)

A few examples are provided in: [src/taylorism/examples.py](https://github.com/UMR-CNRM/taylorism/blob/master/src/taylorism/examples.py)
